{
  lib,
  config,
  pkgs,
  ...
}: let
  cfg = config.services.vm_jellyfin;
in {
  options.services.vm_jellyfin = {
    enable = lib.mkEnableOption "Enable minimal config";
  };
  config = lib.mkIf cfg.enable {
    environment.systemPackages = [pkgs.cifs-utils];
    # Intel Hardware Acceleration config
    nixpkgs.config.packageOverrides = pkgs: {
      vaapiIntel = pkgs.vaapiIntel.override { enableHybridCodec = true; };
    };
    hardware.graphics = {
      enable = true;
      extraPackages = with pkgs; [
        intel-media-driver
        intel-vaapi-driver # previously vaapiIntel
        vaapiVdpau
        libvdpau-va-gl
        intel-compute-runtime # OpenCL filter support (hardware tonemapping and subtitle burn-in)
        vpl-gpu-rt # QSV on 11th gen or newer
      ];
    };
    services.jellyfin = {
      enable = true;
      user = "tbarnouin";
      openFirewall = true;
    };
    fileSystems."/mnt/media" = {
      device = "192.168.1.125:/BIGDATA";
      fsType = "nfs";
      options = [
        "x-systemd.automount"
        "noauto"
      ];
    };
  };
}
